==> process-optaplanner-springboot-1.6.0.Final-sources.jar: org/kie/kogito/examples/Flights_18_TaskOutput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.examples;

import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.UserTask;
import org.kie.kogito.UserTaskParam.ParamType;
import org.kie.kogito.UserTaskParam;

@UserTask(taskName = "approveDenyPassenger", processName = "flights")
public class Flights_18_TaskOutput implements org.kie.kogito.MapOutput {

    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap<>();
        params.put("isPassengerApproved", this.isPassengerApproved);
        return params;
    }

    public static Flights_18_TaskOutput fromMap(Map<String, Object> params) {
        org.kie.kogito.examples.Flights_18_TaskOutput result = new Flights_18_TaskOutput();
        result.isPassengerApproved = (java.lang.Boolean) params.get("isPassengerApproved");
        return result;
    }

    @UserTaskParam(value = ParamType.OUTPUT)
    private java.lang.Boolean isPassengerApproved;

    public java.lang.Boolean getIsPassengerApproved() {
        return isPassengerApproved;
    }

    public void setIsPassengerApproved(java.lang.Boolean isPassengerApproved) {
        this.isPassengerApproved = isPassengerApproved;
    }
}
// Task output model for user task 'Approve/Deny Passenger' in process 'flights'

==> process-optaplanner-springboot-1.7.0.Final-sources.jar: org/kie/kogito/examples/Flights_18_TaskOutput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.examples;

import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.UserTask;
import org.kie.kogito.UserTaskParam.ParamType;
import org.kie.kogito.UserTaskParam;

@UserTask(taskName = "approveDenyPassenger", processName = "flights")
public class Flights_18_TaskOutput implements org.kie.kogito.MapOutput {

    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap<>();
        params.put("isPassengerApproved", this.isPassengerApproved);
        return params;
    }

    public static Flights_18_TaskOutput fromMap(Map<String, Object> params) {
        org.kie.kogito.examples.Flights_18_TaskOutput result = new Flights_18_TaskOutput();
        result.isPassengerApproved = (java.lang.Boolean) params.get("isPassengerApproved");
        return result;
    }

    @UserTaskParam(value = ParamType.OUTPUT)
    private java.lang.Boolean isPassengerApproved;

    public java.lang.Boolean getIsPassengerApproved() {
        return isPassengerApproved;
    }

    public void setIsPassengerApproved(java.lang.Boolean isPassengerApproved) {
        this.isPassengerApproved = isPassengerApproved;
    }
}
// Task output for user task 'Approve/Deny Passenger' in process 'flights'
